==> openshift-model-config-6.2.0-sources.jar: io/fabric8/openshift/api/model/config/v1/KeystoneIdentityProviderFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface KeystoneIdentityProviderFluent<A extends KeystoneIdentityProviderFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildCa instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConfigMapNameReference getCa();
  public ConfigMapNameReference buildCa();
  public A withCa(ConfigMapNameReference ca);
  public Boolean hasCa();
  public A withNewCa(String name);
  public KeystoneIdentityProviderFluent.CaNested<A> withNewCa();
  public KeystoneIdentityProviderFluent.CaNested<A> withNewCaLike(ConfigMapNameReference item);
  public KeystoneIdentityProviderFluent.CaNested<A> editCa();
  public KeystoneIdentityProviderFluent.CaNested<A> editOrNewCa();
  public KeystoneIdentityProviderFluent.CaNested<A> editOrNewCaLike(ConfigMapNameReference item);
  public String getDomainName();
  public A withDomainName(String domainName);
  public Boolean hasDomainName();
  
  /**
   * This method has been deprecated, please use method buildTlsClientCert instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretNameReference getTlsClientCert();
  public SecretNameReference buildTlsClientCert();
  public A withTlsClientCert(SecretNameReference tlsClientCert);
  public Boolean hasTlsClientCert();
  public A withNewTlsClientCert(String name);
  public KeystoneIdentityProviderFluent.TlsClientCertNested<A> withNewTlsClientCert();
  public KeystoneIdentityProviderFluent.TlsClientCertNested<A> withNewTlsClientCertLike(SecretNameReference item);
  public KeystoneIdentityProviderFluent.TlsClientCertNested<A> editTlsClientCert();
  public KeystoneIdentityProviderFluent.TlsClientCertNested<A> editOrNewTlsClientCert();
  public KeystoneIdentityProviderFluent.TlsClientCertNested<A> editOrNewTlsClientCertLike(SecretNameReference item);
  
  /**
   * This method has been deprecated, please use method buildTlsClientKey instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretNameReference getTlsClientKey();
  public SecretNameReference buildTlsClientKey();
  public A withTlsClientKey(SecretNameReference tlsClientKey);
  public Boolean hasTlsClientKey();
  public A withNewTlsClientKey(String name);
  public KeystoneIdentityProviderFluent.TlsClientKeyNested<A> withNewTlsClientKey();
  public KeystoneIdentityProviderFluent.TlsClientKeyNested<A> withNewTlsClientKeyLike(SecretNameReference item);
  public KeystoneIdentityProviderFluent.TlsClientKeyNested<A> editTlsClientKey();
  public KeystoneIdentityProviderFluent.TlsClientKeyNested<A> editOrNewTlsClientKey();
  public KeystoneIdentityProviderFluent.TlsClientKeyNested<A> editOrNewTlsClientKeyLike(SecretNameReference item);
  public String getUrl();
  public A withUrl(String url);
  public Boolean hasUrl();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface CaNested<N> extends Nested<N>,ConfigMapNameReferenceFluent<KeystoneIdentityProviderFluent.CaNested<N>>{
    public N and();
    public N endCa();
    
  }
  public interface TlsClientCertNested<N> extends Nested<N>,SecretNameReferenceFluent<KeystoneIdentityProviderFluent.TlsClientCertNested<N>>{
    public N and();
    public N endTlsClientCert();
    
  }
  public interface TlsClientKeyNested<N> extends Nested<N>,SecretNameReferenceFluent<KeystoneIdentityProviderFluent.TlsClientKeyNested<N>>{
    public N and();
    public N endTlsClientKey();
    
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/KeystoneIdentityProviderFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface KeystoneIdentityProviderFluent<A extends KeystoneIdentityProviderFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildCa instead.
   * @return The buildable object.
   */
  @Deprecated
  public ConfigMapNameReference getCa();
  public ConfigMapNameReference buildCa();
  public A withCa(ConfigMapNameReference ca);
  public Boolean hasCa();
  public A withNewCa(String name);
  public KeystoneIdentityProviderFluent.CaNested<A> withNewCa();
  public KeystoneIdentityProviderFluent.CaNested<A> withNewCaLike(ConfigMapNameReference item);
  public KeystoneIdentityProviderFluent.CaNested<A> editCa();
  public KeystoneIdentityProviderFluent.CaNested<A> editOrNewCa();
  public KeystoneIdentityProviderFluent.CaNested<A> editOrNewCaLike(ConfigMapNameReference item);
  public String getDomainName();
  public A withDomainName(String domainName);
  public Boolean hasDomainName();
  
  /**
   * This method has been deprecated, please use method buildTlsClientCert instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretNameReference getTlsClientCert();
  public SecretNameReference buildTlsClientCert();
  public A withTlsClientCert(SecretNameReference tlsClientCert);
  public Boolean hasTlsClientCert();
  public A withNewTlsClientCert(String name);
  public KeystoneIdentityProviderFluent.TlsClientCertNested<A> withNewTlsClientCert();
  public KeystoneIdentityProviderFluent.TlsClientCertNested<A> withNewTlsClientCertLike(SecretNameReference item);
  public KeystoneIdentityProviderFluent.TlsClientCertNested<A> editTlsClientCert();
  public KeystoneIdentityProviderFluent.TlsClientCertNested<A> editOrNewTlsClientCert();
  public KeystoneIdentityProviderFluent.TlsClientCertNested<A> editOrNewTlsClientCertLike(SecretNameReference item);
  
  /**
   * This method has been deprecated, please use method buildTlsClientKey instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretNameReference getTlsClientKey();
  public SecretNameReference buildTlsClientKey();
  public A withTlsClientKey(SecretNameReference tlsClientKey);
  public Boolean hasTlsClientKey();
  public A withNewTlsClientKey(String name);
  public KeystoneIdentityProviderFluent.TlsClientKeyNested<A> withNewTlsClientKey();
  public KeystoneIdentityProviderFluent.TlsClientKeyNested<A> withNewTlsClientKeyLike(SecretNameReference item);
  public KeystoneIdentityProviderFluent.TlsClientKeyNested<A> editTlsClientKey();
  public KeystoneIdentityProviderFluent.TlsClientKeyNested<A> editOrNewTlsClientKey();
  public KeystoneIdentityProviderFluent.TlsClientKeyNested<A> editOrNewTlsClientKeyLike(SecretNameReference item);
  public String getUrl();
  public A withUrl(String url);
  public Boolean hasUrl();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface CaNested<N> extends Nested<N>,ConfigMapNameReferenceFluent<KeystoneIdentityProviderFluent.CaNested<N>>{
    public N and();
    public N endCa();
    
  }
  public interface TlsClientCertNested<N> extends Nested<N>,SecretNameReferenceFluent<KeystoneIdentityProviderFluent.TlsClientCertNested<N>>{
    public N and();
    public N endTlsClientCert();
    
  }
  public interface TlsClientKeyNested<N> extends Nested<N>,SecretNameReferenceFluent<KeystoneIdentityProviderFluent.TlsClientKeyNested<N>>{
    public N and();
    public N endTlsClientKey();
    
  }
  
}
